isConnected property

Future<bool> get isConnected

Check if user is connecter Return true if user is connected Return false if user is not connected Return false if user is connected but token is expired

Implementation

Future<bool> get isConnected async {
  if (await _alreadyAuthenticated()) {
    return true;
  }
  if (await _getStorageValue(_refrshTokenField) != null) {
    await _silentLogin();
  }
  return await _alreadyAuthenticated();
}