OpenIdConfiguration class

Configuration for OpenId

clientId is the client id of the application clientSecret is the client secret of the application uri is the uri of the OpenId server scopes is the list of scopes to request

Examplefor local Keycloak server:

OpenIdConfiguration(
 clientId: "example-id",
 clientSecret: "example-clientSecret",
 uri: Uri.parse("http://localhost:8080/realm/master"),
 scopes: ["openid", "profile"],
 );

OpenId is an interceptor for Dio that handles OpenId authentication

Constructors

OpenIdConfiguration({required String clientId, required String clientSecret, required Uri uri, required List<String> scopes})

Properties

clientId String
final
clientSecret String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final
uri Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited